# example1.py
#
# This example illustrates how to send two queries to SQL Server in a
# command batch.  It binds each set of results and prints the rows.
import sys
from mssqldb import *

import exutils

print 'Demo of SQL queries in a command batch\n'

# Initialize DB-Library.
if not dbinit():
    sys.exit(1)

# Install the user-supplied error-handling and message-handling
# routines. They are defined at the bottom of this source file.
dberrhandle(exutils.err_handler)
dbmsghandle(exutils.msg_handler)

# Get a LOGINREC structure and fill it with the necessary login
# information.
login = dblogin()
login.dbsetluser(exutils.USER)
login.dbsetlpwd(exutils.PASSWORD)
login.dbsetlapp('example1')

# Get a DBPROCESS structure for communicating with SQL Server.  A NULL
# servername defaults to the server specified by DSQUERY.
dbproc = login.dbopen(exutils.SERVER)

# We are going to retrieve some information, from a table named
# "sysobjects", regarding names of system tables and stored
# procedures.
# We will submit two queries.  The first finds all the rows that
# describe system tables.  The second finds all the rows that describe
# stored procedures.  The program will only look at the first 10 rows
# that describe stored procedures.

# First, put the commands into the command buffer.
dbproc.dbcmd("select name, type, id, crdate from sysobjects")
dbproc.dbcmd(" where type = 'S' ")
dbproc.dbcmd("select name, type, id, crdate from sysobjects")
dbproc.dbcmd(" where type = 'P' ")

# Sql Server processes the command batch in the following order:
#
# 1) It will check for syntax errors (i.e., "use database pubs"
#    is syntactically incorrect; it should be "use pubs").
# 2) The second check is a semantic check (i.e., "select * from 
#    titels" will be incorrect because the spelling should be
#    "titles".)
# 3) The third check occurs in the actual execution phase. This 
#    check involves issues like permissions or memory problems.
# 
# In the execution phase, dbsqlexec() and dbresults() can return the
# value "SUCCEED", which means there are more commands in the batch to
# process and that that command was successful. A value of "FAIL"
# means that the query failed but there may be more commands in the
# batch to process. A value of "NO_MORE_RESULTS" means that there are
# no more commands in the batch to process.  Therefore, the programmer
# must check the return values after dbsqlexec() and dbresults(), as
# illustrated below.

# Send the commands to SQL Server and start execution.
dbproc.dbsqlexec()

# Process each command until there are no more.

DATELEN = 26
TYPELEN = 2

while 1:
    result_code = dbproc.dbresults()
    if result_code == NO_MORE_RESULTS:
        break
    name = DataBuf(SQLCHAR, SQLMAXNAME)
    type = DataBuf(SQLCHAR, TYPELEN)
    id = DataBuf(SQLINT4)
    crdate = DataBuf(SQLCHAR, DATELEN)
    if result_code == SUCCEED:
        # Bind program variables.
        dbproc.dbbind(1, name);
        dbproc.dbbind(2, type);
        dbproc.dbbind(3, id);
        dbproc.dbbind(4, crdate);

        # Print appropriate header for the type of data coming back.
        if dbproc.dbcurcmd() == 1:
            print '\n System Table Objects: \n'
        else:
            print '\n Procedure Objects: \n'

        # Now print the rows.
        while dbproc.dbnextrow() != NO_MORE_ROWS:
            # If this is the 2nd command and 10th row, flush the rest
            # of the rows for that command.
            if dbproc.dbcurcmd() == 2 and dbproc.dbcurrow() > 10:
                continue
            print '%s %s %d %s' % (name, type, id.get(), crdate)
# Close our connection and exit the program.
dbexit()
