# example5.c
#
# This example illustrates dbconvert().  It converts a number of
# constants to strings, a number of strings to numerical or binary
# quantities, and a number of numerical quantities to other numerical
# types.
import sys
from mssqldb import *

import exutils

ARRAY_LEN = 20

# These variables will hold the results of data conversions.
my_binary_array = DataBuf(SQLBINARY, ARRAY_LEN)
my_binary_array.set('\x12\x34\x56\x78\x9a\xbc\xde\xf0')
my_flt8 = DataBuf(SQLFLT8)
my_int4 = DataBuf(SQLINT4)
my_money = DataBuf(SQLMONEY)
my_string = DataBuf(SQLCHAR, ARRAY_LEN)
my_date = DataBuf(SQLDATETIME)

print "Demo of SQL queries in a command batch\n"

# Initialize DB-Library. */
if not dbinit():
    sys.exit(1)

# Install the user-supplied error-handling and message-handling
# routines. They are defined at the bottom of this source file.
dberrhandle(exutils.err_handler)
dbmsghandle(exutils.msg_handler)

# Convert numerical and binary constants to strings.
dbconvert(my_binary_array, my_string)
print "Binary constant 0x123456789abcdef0 converted to string \"%s\"." \
      % my_string

my_flt8.set(55.555)
dbconvert(my_flt8, my_string)
print "Floating-pt constant 55.555 converted to string \"%s\"." % my_string

# Convert string constants to numerical and binary quantities.
dbconvert("123", my_int4)
print "String constant \"123\" converted to 4-byte integer %d." % my_int4.get()

dbconvert("0xfedc", my_binary_array)
my_binary_array.type = SQLINT4          # don't try this at home
print "String constant \"0xfedc\" converted to binary sequence %x." \
      % my_binary_array.get()
my_binary_array.type = SQLBINARY        # don't try this at home

dbconvert("123.456", my_flt8)
print "String constant \"123.456\" converted to floating-pt number %f." \
      % my_flt8.get()

# Convert numerical types to other numerical types.
my_flt8.set(98.76);
dbconvert(my_flt8, my_money)
dbconvert(my_money, my_string)
print "floating-pt number %f converted to money value %s." \
      % (my_flt8.get(), my_string)

dbconvert(my_money, my_flt8)
print "money value %s converted to floating-pt value %f." \
      % (my_string, my_flt8.get())

#  Datetime conversions:  
#
# Many formats are acceptable for dates.  For a list of these formats,
# see the Commands Reference datatypes page.

dbconvert("November 11, 1955", my_date)
my_date.type = SQLMONEY                 # well, the example does this
dbconvert(my_date, my_string)
my_date.type = SQLDATETIME              # get it back to what it should be

print "Internal date representation converted to string value %s." \
      % my_string

dbdatename(DBDATE_DY, my_date)

print "Day-of-year extracted from internal representation: %s." \
      % dbdatename(DBDATE_DY, my_date)

print "Day-of-week extracted from internal representation: %s." \
      % dbdatename(DBDATE_DW, my_date)

dbexit()
